.parse_active_effects: Evaluate terms in a duremstats formula into effect config lists
Description
Evaluate terms in a duremstats formula into effect config lists
Usage
.parse_active_effects(formula)
Value
A list of named lists, each with $effect, $scaling,
and $consider_type.
Arguments
- formula
Formula such as
~ activeTie() + activeOutdegreeSender(scaling = "std")