remify_durem objectsCalled by remstats when reh inherits from
"remify_durem". Builds a dual-event edgelist (one "start" row
and one "end" row per event), applies psi weighting, and calls
tomstats twice — once for the start model, once for the end model.
.remstats_durem(
reh,
start_effects = NULL,
end_effects = NULL,
psi_start = 1,
psi_end = 1,
attr_actors = NULL,
attr_dyads = NULL,
memory = c("full", "window", "decay", "interval"),
memory_value = NA,
start = 2,
stop = Inf,
display_progress = FALSE
)A remstats_durem object.
A remify_durem object.
Formula for start-model statistics (remstats syntax).
Formula for end-model statistics.
Numeric. Duration exponent for start-model history
weighting. Event weight is w * (end - time + 1)^psi_start.
Default 1.
Numeric. Duration exponent for end-model history weighting.
Default 1.
optionally, an object of class
"data.frame" that contains exogenous attributes for
actors (see Details).
optionally, an object of class data.frame or
matrix containing attribute information for dyads (see Details).
The memory to be used. See `Details'.
Numeric value indicating the memory parameter. Default
is NA, which is only valid for memory = "full" (no memory
parameter required). See `Details'.
should a progress bar for the computation of the endogenous statistics be shown (TRUE) or not (FALSE)?