degreeDiff: degreeDiff

View source: R/effects.R

degreeDiffR Documentation

degreeDiff

Description

Specifies the statistic for a 'degreeDiff' effect in the tie-oriented model.

Usage

degreeDiff(scaling = c("none", "std"), consider_type = "ignore")

Arguments

scaling

the method for scaling the degree statistic. Default is to not scale the statistic (scaling = "none"). Alternatively, standardization of the degree difference per time point can be requested with 'std'.

consider_type

character. Controls how event types are handled: "ignore" (default): aggregate over all event types (one statistic); "separate": compute C type-specific statistics, where the type-c statistic for a dyad reflects past type-c events on that actor pair ; "interact": compute C^2 statistics capturing past-event-type x dyad-type interactions (only meaningful with extend_riskset_by_type=TRUE in remify object). Also accepts FALSE (-> "ignore") and TRUE (-> "separate") for backward compatibility.

Details

A degreeDiff effect refers to the tendency for dyads to increase their interaction rate if the absolute difference in degree for the two actors in the pair increases. The statistic at timepoint t for dyad (i,j) is equal to the difference between the following two values: the number of events before timepoint t that involved actor i and actor j, respectively. The degreeDiff effect is only defined for undirected events.

Value

List with all information required by 'remstats::remstats()' to compute the statistic.

See Also

degreeMin, degreeMax or totaldegreeDyad for other types of degree effects for undirected events.

Examples

reh_tie <- remify::remify(history, model = "tie", directed = FALSE)
effects <- ~ degreeDiff()
remstats(reh = reh_tie, tie_effects = effects)


remstats documentation built on July 15, 2026, 5:07 p.m.