dot-parse_active_effects: Evaluate terms in a 'duremstats' formula into effect config...

.parse_active_effectsR Documentation

Evaluate terms in a duremstats formula into effect config lists

Description

Evaluate terms in a duremstats formula into effect config lists

Usage

.parse_active_effects(formula)

Arguments

formula

Formula such as ~ activeTie() + activeOutdegreeSender(scaling = "std")

Value

A list of named lists, each with $effect, $scaling, and $consider_type.


remstats documentation built on July 15, 2026, 5:07 p.m.