indegreeSender: indegreeSender

View source: R/effects.R

indegreeSenderR Documentation

indegreeSender

Description

Specifies the statistic for an 'indegreeSender' effect in the tie-oriented model or the sender activity rate step of the actor-oriented model.

Usage

indegreeSender(scaling = c("none", "prop", "std"), consider_type = "ignore")

Arguments

scaling

the method for scaling the degree statistic. Default is to not scale the statistic (scaling = "none"). Alternatively, scaling of the raw degree counts by the number of past events at time t can be requested with 'prop' or standardization of the raw degree counts per time point can be requested with 'std'.

consider_type

character. Controls how event types are handled: "ignore" (default): aggregate over all event types (one statistic); "separate": compute C type-specific statistics, where the type-c statistic for a dyad reflects past type-c events on that actor pair ; "interact": compute C^2 statistics capturing past-event-type x dyad-type interactions (only meaningful with extend_riskset_by_type=TRUE in remify object). Also accepts FALSE (-> "ignore") and TRUE (-> "separate") for backward compatibility.

Details

An indegree of the sender effect refers to the tendency for actors to send events if they have received more past events. The statistic at timepoint t for dyad (i,j) (tie-oriented model) or sender i (actor-oriented model) is equal to the number of events received by actor i before timepoint t. Note that the 'indegreeSender' effect is only defined for directed events.

Optionally, a scaling method can be set with scaling. By scaling the degree count by the total number of past events, the statistic refers to the fraction of past events that were received by actor i. At the first time point, when no events did previously occur, it is assumed that every actor is equally likely to send a message and the statistic is set equal to 1/n, where n refers to the number of actors.

Value

List with all information required by 'remstats::remstats()' to compute the statistic.

See Also

indegreeReceiver, outdegreeSender, outdegreeReceiver, totaldegreeSender, or totaldegreeReceiver for other types of degree effects.

Examples

reh_tie <- remify::remify(history, model = "tie")
effects <- ~ indegreeSender()
remstats(reh = reh_tie, tie_effects = effects)

reh_actor <- remify::remify(history, model = "actor")
remstats(reh = reh_actor, sender_effects = effects)


remstats documentation built on July 15, 2026, 5:07 p.m.