Learn R Programming

remstats (version 4.1.0)

inertia: inertia

Description

Specifies the statistic for an inertia effect in the tie-oriented model or the receiver choice step of the actor-oriented model.

Usage

inertia(scaling = c("none", "prop", "std"), consider_type = "ignore")

Value

List with all information required by `remstats::remstats()` to compute the statistic.

Arguments

scaling

the method for scaling the inertia statistic. Default is to not scale the statistic (scaling = "none"). Alternatively, the statistics can be scaled by specifying 'prop', in which raw counts are divided by the outdegree of the sender at time t (see 'details') or standardization of the raw counts per time point can be requested with 'std'.

consider_type

character. Controls how event types are handled: "ignore" (default): aggregate over all event types (one statistic); "separate": compute C type-specific statistics, where the type-c statistic for a dyad reflects past type-c events on that actor pair ; "interact": compute C^2 statistics capturing past-event-type x dyad-type interactions (only meaningful with extend_riskset_by_type=TRUE in remify object). Also accepts FALSE (-> "ignore") and TRUE (-> "separate") for backward compatibility.

Details

An inertia effect refers to the tendency for dyads to repeatedly interact with each other (tie-oriented model) or for actors to repeatedly choose the same actor as receiver of their events (actor-oriented model). The statistic at timepoint t for dyad (i,j) resp. receiver j is equal to the number of (i,j) events before timepoint t.

Optionally, a scaling method can be set with scaling. By scaling the inertia count by the outdegree of the sender ("prop"), the statistic refers to the fraction of messages send by actor i that were send to actor j. If actor i hasn't send any messages yet it can be assumed that every actor is equally likely to receive a message from i and the statistic is set equal to 1/(n-1), where n refers to the number of actors. The resulting statistic is similar to the "FrPSndSnd" statistic in the R package 'relevent', or the persistence statistic in Section 2.2.2 of Butts (2008). Note that this scaling method is only defined for directed events.

Examples

Run this code
reh_tie <- remify::remify(history, model = "tie")
effects <- ~ inertia()
remstats(reh = reh_tie, tie_effects = effects)

reh_actor <- remify::remify(history, model = "actor")
remstats(reh = reh_actor, receiver_effects = effects)

Run the code above in your browser using DataLab