itp: itp

View source: R/effects.R

itpR Documentation

itp

Description

Specifies the statistic for an incoming two-path effect.

Usage

itp(unique = FALSE, scaling = c("none", "std"), consider_type = "ignore")

Arguments

unique

A logical value indicating whether to sum the minimum of events with third actors (FALSE, default) or the number of third actors that create a new, unique two-path (TRUE). See details for more information.

scaling

The method for scaling the triad statistic. The default value is "none", which means the statistic is not scaled. Alternatively, you can set it to "std" to request standardization of the raw counts per time point.

consider_type

character. Controls how event types are handled: "ignore" (default): aggregate over all event types (one statistic); "separate": compute C type-specific statistics, where the type-c statistic for a dyad reflects past type-c events on that actor pair ; "interact": compute C^2 statistics capturing past-event-type x dyad-type interactions (only meaningful with extend_riskset_by_type=TRUE in remify object). Also accepts FALSE (-> "ignore") and TRUE (-> "separate") for backward compatibility.

Details

The incoming two-path effect describes the propensity of dyads to interact based on the number of past incoming two-paths between them. By default, the statistic at timepoint t for the dyad (i,j) is computed as the sum of the minimum occurrences of past (j,h) and (h,i) events across all actors h.

When the unique parameter is set to TRUE, a different approach is taken. In this case, the statistic counts the number of actors h that contribute to the creation of a new, distinct two-path between actors i and j.

Additionally, it is possible to specify a scaling method using the scaling parameter.

Please note that the incoming two-path effect, 'itp', is exclusively defined for directed events.

Value

List with all information required by 'remstats::remstats()' to compute the statistic.

References

Butts, C. (2008). A relational event framework for social action. Sociological Methodology.

See Also

otp, osp, or isp for other types of triadic effects for directed relational events and sp for triadic effects for undirected relational events.

Examples

reh_tie <- remify::remify(history, model = "tie")
effects <- ~ itp()
remstats(reh = reh_tie, tie_effects = effects)

reh_actor <- remify::remify(history, model = "actor")
remstats(reh = reh_actor, receiver_effects = effects)


remstats documentation built on July 15, 2026, 5:07 p.m.