psABXA: psABXA

View source: R/effects.R

psABXAR Documentation

psABXA

Description

Specifies the statistic for a participation shift AB-XA.

Usage

psABXA(consider_type = "ignore")

Arguments

consider_type

character. Controls how event types are handled: "ignore" (default): aggregate over all event types (one statistic); "separate": compute C type-specific statistics, where the type-c statistic for a dyad reflects past type-c events on that actor pair ; "interact": compute C^2 statistics capturing past-event-type x dyad-type interactions (only meaningful with extend_riskset_by_type=TRUE in remify object). Also accepts FALSE (-> "ignore") and TRUE (-> "separate") for backward compatibility.

Details

The AB-XA participation shift refers to one of Gibson's (2003) dyadic participation shifts. The AB-XA pshift refers to a tendency for turn usurping (here, the next sender is not in the previous event and the next receiver is the previous sender). For each timepoint t, the psABXA statistic is equal to one for the dyads that will create the participation shift if they would occur in the edgelist at time t and equal to zero for the dyads that will not create this participation shift. If consider_type is set to TRUE, the type of the AB event and the type of the XA events have to be equal. If it is set to FALSE, the participation shift is set to one for every XA event, regardless of the event type. If multiple events in the edgelist occur at the same time point, the order of these events determines whether the pshift is observed. Note that the AB-XA pshift is only defined for directed events.

Value

List with all information required by 'remstats::remstats()' to compute the statistic.

See Also

psABBA, psABBY, psABXB, psABXY or psABAY for other dyadic participation shifts.

Examples

reh_tie <- remify::remify(history, model = "tie")
effects <- ~ psABXA()
remstats(reh = reh_tie, tie_effects = effects)


remstats documentation built on July 15, 2026, 5:07 p.m.