Learn R Programming

remstats (version 4.1.0)

recencyContinue: recencyContinue

Description

Specifies the statistic for a recency continue effect in the effects argument of tomstats or the receiver_effects argument of aomstats.

Usage

recencyContinue(consider_type = "ignore")

Value

List with all information required by `remstats::remstats()` to compute the statistic.

Arguments

consider_type

character. Controls how event types are handled: "ignore" (default): aggregate over all event types (one statistic); "separate": compute C type-specific statistics, where the type-c statistic for a dyad reflects past type-c events on that actor pair ; "interact": compute C^2 statistics capturing past-event-type x dyad-type interactions (only meaningful with extend_riskset_by_type=TRUE in remify object). Also accepts FALSE (-> "ignore") and TRUE (-> "separate") for backward compatibility.

Details

The recencyContinue effect refers to a recency statistic similar to what is described in Vu et al. (2017) and Mulder and Leenders (2019). For each timepoint t, for directed dyad (i,j) the statistic is equal to 1/(the time that has past since the dyad was last active + 1).

See Also

rrankSend, rrankReceive, recencySendSender, recencyReceiveSender, recencyReceiveSender and recencyReceiveReceiver for other type of recency effects

Examples

Run this code
effects <- ~ recencyContinue()
reh_tie <- remify::remify(history, model = "tie")
remstats(tie_effects = effects, reh = reh_tie)

reh_actor <- remify::remify(history, model = "actor")
remstats(receiver_effects = effects, reh = reh_actor)

Run the code above in your browser using DataLab