recencyReceiveReceiver: recencyReceiveReceiver

View source: R/effects.R

recencyReceiveReceiverR Documentation

recencyReceiveReceiver

Description

Specifies the statistic for a recency receive of receiver effect in the effects argument of tomstats or the receiver_effects argument of aomstats.

Usage

recencyReceiveReceiver(consider_type = "ignore")

Arguments

consider_type

character. Controls how event types are handled: "ignore" (default): aggregate over all event types (one statistic); "separate": compute C type-specific statistics, where the type-c statistic for a dyad reflects past type-c events on that actor pair ; "interact": compute C^2 statistics capturing past-event-type x dyad-type interactions (only meaningful with extend_riskset_by_type=TRUE in remify object). Also accepts FALSE (-> "ignore") and TRUE (-> "separate") for backward compatibility.

Details

The recencyReceiveReceiver effect refers to a recency statistic similar to what is described in Vu et al. (2017) and Mulder and Leenders (2019). For each timepoint t, for directed dyad (i,j) the statistic is equal to 1/(the time that has past since receiver j was last active as receiver + 1). Note that the 'recencyReceiveReceiver' effect is only defined for directed events.

Value

List with all information required by 'remstats::remstats()' to compute the statistic.

See Also

rrankSend, rrankReceive, recencySendSender, recencyReceiveSender, recencyReceiveSender and recencyContinue for other type of recency effects

Examples

effects <- ~ recencyReceiveReceiver()
reh_tie <- remify::remify(history, model = "tie")
remstats(tie_effects = effects, reh = reh_tie)

reh_actor <- remify::remify(history, model = "actor")
remstats(receiver_effects = effects, reh = reh_actor)


remstats documentation built on July 15, 2026, 5:07 p.m.