reciprocity: reciprocity

View source: R/effects.R

reciprocityR Documentation

reciprocity

Description

Specifies the statistic for a reciprocity effect in the tie-oriented model or the receiver choice step of the actor-oriented model.

Usage

reciprocity(scaling = c("none", "prop", "std"), consider_type = "ignore")

Arguments

scaling

the method for scaling the reciprocity statistic. Default is to not scale the statistic but keep the raw 'counts'. Alternatively, the statistics can be scaled by 'prop', in which raw counts are divided by the indegree of the sender at time t (see 'details') or standardization of the raw counts per time point can be requested with 'std'.

consider_type

character. Controls how event types are handled: "ignore" (default): aggregate over all event types (one statistic); "separate": compute C type-specific statistics, where the type-c statistic for a dyad reflects past type-c events on that actor pair ; "interact": compute C^2 statistics capturing past-event-type x dyad-type interactions (only meaningful with extend_riskset_by_type=TRUE in remify object). Also accepts FALSE (-> "ignore") and TRUE (-> "separate") for backward compatibility.

Details

A reciprocity effect refers to the tendency for actors to reciprocate past interactions. The statistic at timepoint t for dyad (i,j) (tie-oriented model) or receiver j (actor-oriented model) is equal to the number of (j,i) events before timepoint t. Note that a reciprocity effect is only defined for directed events.

Optionally, a scaling method can be set with scaling. By scaling the reciprocity count by the indegree of the sender, the statistic refers to the fraction of messages received by actor i that were received from actor j. If actor i hasn't received any messages yet it can be assumed that actor i is equally likely to receive a message from every actor and the statistic is set equal to 1/(n-1), where n refers to the number of actors. The resulting statistic is similar to the "FrRecSnd" statistic in the R package 'relevent'.

Value

List with all information required by 'remstats::remstats()' to compute the statistic.

Examples

reh_tie <- remify::remify(history, model = "tie")
effects <- ~ reciprocity()
remstats(reh = reh_tie, tie_effects = effects)

reh_actor <- remify::remify(history, model = "actor")
remstats(reh = reh_actor, receiver_effects = effects)


remstats documentation built on July 15, 2026, 5:07 p.m.