rrankSend: rrankSend

View source: R/effects.R

rrankSendR Documentation

rrankSend

Description

Specifies the statistic for a recency rank send effect in the effects argument of tomstats or the receiver_effects argument of aomstats.

Usage

rrankSend(consider_type = "ignore")

Arguments

consider_type

character. Controls how event types are handled: "ignore" (default): aggregate over all event types (one statistic); "separate": compute C type-specific statistics, where the type-c statistic for a dyad reflects past type-c events on that actor pair ; "interact": compute C^2 statistics capturing past-event-type x dyad-type interactions (only meaningful with extend_riskset_by_type=TRUE in remify object). Also accepts FALSE (-> "ignore") and TRUE (-> "separate") for backward compatibility.

Details

The rrankSend effect refers to a rank-based recency effect, as described in section 2.2.5 of Butts (2008). For each timepoint t, for directed dyad (i,j) the statistic is equal to the inverse of the rank of receiver j among the actors to which sender i has most recently send past events. Note that the 'rrankSend' effect is only defined for directed events.

Value

List with all information required by 'remstats::remstats()' to compute the statistic.

See Also

rrankReceive, recencySendSender, recencySendReceiver, recencyReceiveSender, recencyReceiveReceiver and recencyContinue for other type of recency effects

Examples

reh_tie <- remify::remify(history, model = "tie")
effects <- ~ rrankSend()
remstats(tie_effects = effects, reh = reh_tie)

reh_actor <- remify::remify(history, model = "actor")
remstats(receiver_effects = effects, reh = reh_actor)


remstats documentation built on July 15, 2026, 5:07 p.m.