| .remstats_durem | R Documentation |
remify_durem objectsCalled by remstats when reh inherits from
"remify_durem". Builds a dual-event edgelist (one "start" row
and one "end" row per event), applies psi weighting, and calls
tomstats twice — once for the start model, once for the end model.
.remstats_durem(
reh,
start_effects = NULL,
end_effects = NULL,
psi_start = 1,
psi_end = 1,
attr_actors = NULL,
attr_dyads = NULL,
memory = c("full", "window", "decay", "interval"),
memory_value = NA,
start = 2,
stop = Inf,
display_progress = FALSE
)
reh |
A |
start_effects |
Formula for start-model statistics (remstats syntax). |
end_effects |
Formula for end-model statistics. |
psi_start |
Numeric. Duration exponent for start-model history
weighting. Event weight is |
psi_end |
Numeric. Duration exponent for end-model history weighting.
Default |
attr_actors |
optionally, an object of class
|
attr_dyads |
optionally, an object of class |
memory |
The memory to be used. See ‘Details’. |
memory_value |
Numeric value indicating the memory parameter. Default
is |
display_progress |
should a progress bar for the computation of the endogenous statistics be shown (TRUE) or not (FALSE)? |
A remstats_durem object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.