View source: R/util_remstats.R
| select_stats | R Documentation |
Select a subset of statistics from a remstats object
select_stats(
object,
tie_effects = NULL,
sender_effects = NULL,
receiver_effects = NULL,
start_effects = NULL,
end_effects = NULL
)
object |
a |
tie_effects |
character vector of statistic names to keep (tomstats only) |
sender_effects |
character vector of statistic names to keep (aomstats only) |
receiver_effects |
character vector of statistic names to keep (aomstats only) |
start_effects |
character vector of statistic names to keep (remstats_durem only) |
end_effects |
character vector of statistic names to keep (remstats_durem only) |
a remstats object of the same class with only the selected statistics
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.