Learn R Programming

remstats (version 4.1.0)

select_stats: Select a subset of statistics from a remstats object

Description

Select a subset of statistics from a remstats object

Usage

select_stats(
  object,
  tie_effects = NULL,
  sender_effects = NULL,
  receiver_effects = NULL,
  start_effects = NULL,
  end_effects = NULL
)

Value

a remstats object of the same class with only the selected statistics

Arguments

object

a remstats object (of class tomstats, aomstats, or remstats_durem)

tie_effects

character vector of statistic names to keep (tomstats only)

sender_effects

character vector of statistic names to keep (aomstats only)

receiver_effects

character vector of statistic names to keep (aomstats only)

start_effects

character vector of statistic names to keep (remstats_durem only)

end_effects

character vector of statistic names to keep (remstats_durem only)