Select a subset of statistics from a remstats object
select_stats(
object,
tie_effects = NULL,
sender_effects = NULL,
receiver_effects = NULL,
start_effects = NULL,
end_effects = NULL
)a remstats object of the same class with only the selected statistics
a remstats object (of class tomstats,
aomstats, or remstats_durem)
character vector of statistic names to keep (tomstats only)
character vector of statistic names to keep (aomstats only)
character vector of statistic names to keep (aomstats only)
character vector of statistic names to keep (remstats_durem only)
character vector of statistic names to keep (remstats_durem only)