Specifies the statistic for a shared partners effect for undirected events.
sp(unique = FALSE, scaling = c("none", "std"), consider_type = "ignore")List with all information required by `remstats::remstats()` to compute the statistic.
A logical value indicating whether to sum the minimum of events with third actors (FALSE, default) or the number of third actors that create a new, unique shared partner (TRUE). See details for more information.
the method for scaling the triad statistic. Default is to not scale the statistic but keep the raw 'counts'. Alternatively, standardization of the raw counts per time point can be requested with 'std'.
character. Controls how event types are handled:
"ignore" (default): aggregate over all event types (one statistic);
"separate": compute C type-specific statistics, where the type-c
statistic for a dyad reflects past type-c events on that actor pair
;
"interact": compute C^2 statistics capturing past-event-type x
dyad-type interactions (only meaningful with extend_riskset_by_type=TRUE in remify object).
Also accepts FALSE (-> "ignore") and TRUE
(-> "separate") for backward compatibility.
The shared partners effect describes the propensity of dyads to interact based on the number of past shared partners between them. By default, the statistic at timepoint t for the undirected dyad (i,j) is computed as the sum of the minimum occurrences of past undirected (i,h) and undirected (j,h) events across all actors h.
When the unique parameter is set to TRUE, a different approach is taken. In this case, the statistic counts the number of actors h that contribute to the creation of a new, distinct shared partner between actors i and j.
Additionally, it is possible to specify a scaling method using the scaling parameter.
Please note that the shared partners effect, 'sp', is exclusively defined for undirected events.
otp, itp, osp, or
isp for triadic effects for directed relational events.
reh_tie <- remify::remify(history, model = "tie", directed = FALSE)
effects <- ~ sp()
remstats(tie_effects = effects, reh = reh_tie)
Run the code above in your browser using DataLab