Learn R Programming

remstats (version 4.1.0)

tie_effects: tie_effects

Description

Overview of statistics in the tie-oriented model, see Details.

Usage

tie_effects(directed = NULL, endogenous = NULL)

Value

Returns a list of available effects and their corresponding statistics.

Arguments

directed

logical value. The function outputs all statistics in the tie-oriented model for directed events if true, or all statistics in the tie-oriented model for undirected events if false.

endogenous

logical value. The function outputs all endogenous statistics in the tie-oriented model if true, or all exogenous statistics if false

Details

Overview of statistics in the tie-oriented model.

Baseline:

  • baseline

Exogenous statistics:

  • send()

  • receive()

  • tie()

  • same()

  • difference()

  • average()

  • minimum()

  • maximum()

  • event()

  • userStat()

Endogenous statistics:

  • indegreeSender()

  • indegreeReceiver()

  • outdegreeSender()

  • outdegreeReceiver()

  • totaldegreeSender()

  • totaldegreeReceiver()

  • totaldegreeDyad()

  • degreeMin()

  • degreeMax()

  • degreeDiff()

  • inertia()

  • reciprocity()

  • otp()

  • itp()

  • osp()

  • isp()

  • sp()

  • psABBA()

  • psABBY()

  • psABXA()

  • psABXB()

  • psABXY()

  • psABAY()

  • psABAB()

  • rrankSend()

  • rrankReceive()

  • recencySendSender()

  • recencySendReceiver()

  • recencyReceiveSender()

  • recencyReceiveReceiver()

  • recencyContinue()

  • FEtype()

Directed vs. undirected availability The set of available effects depends on whether events are directed. Use tie_effects(directed = TRUE) or tie_effects(directed = FALSE) to obtain the authoritative list for the current package version.

For undirected events (directed = FALSE), the available tie-model effects are:

  • baseline, FEtype

  • tie, same, difference, average, minimum, maximum

  • event, userStat

  • inertia, totaldegreeDyad, degreeMin, degreeMax, degreeDiff

  • sp, psABAY, psABAB, recencyContinue

See Also

actor_effects for the actor-oriented model, and active_effects for the additional active-state statistics available in models of events with a duration.

Examples

Run this code
# List of available effects 
tie_effects()

# List of available effects for undirected networks
tie_effects(directed = FALSE)

# List of available endogenous effects for undirected networks
tie_effects(directed = FALSE, endogenous = TRUE)

Run the code above in your browser using DataLab